* =======================================================================
* Kluever/Rodon BJPS: Explaining policy position choice of Europarties
* =======================================================================


clear
clear matrix
set mem 10m
set more off

cd "C:\Users\Heike\Dropbox\Party Paper\BJPS Replication Archive\" 
use "C:\Users\Heike\Dropbox\Party Paper\BJPS Replication Archive\KlueverRodonBJPS.dta", clear 
log using KlueverRodon_BJPS, replace




* Variables
* =========
* dist_rile					= Left-right distance between national and Europarty
* dist_rile_eu              = Two dimensional distance between national and Europarty 
* lagseats_rel          	= Legislative resources
* dist_voter_rile       	= Left-right distance between national party and electorate 
* dist_voter_rile_eu    	= Two dimensional distance between national party and electorate
* logmemduration            = Duration of EU membership
* salience                  = Salience of EP elections
* govern                    = Government participation
* lagdist_rile              = Lagged dependent variable (left-right)
* lagdist_rile_eu           = Lagged dependent variable (two-dimensional)
* dist_rile_lagged          = Left-right distance between national and Europarty based on estimates from previous election
* dist_rile_eu_lagged       = Two dimensional distance between national and Europarty based on estimates from previous election
* lagdist_rile_lagged       = Lagged dependent variable (left-right, estimates from previous election)
* lagdist_rile_eu_lagged    = Lagged dependent variable (two-dimensional, estimates from previous election)
* pophdth                   = Country size (Population in hundred thousand inhabitants)
* pfamily                   = Party family 
* party_year                = Cluster variable based on Europarty and year
* rile						= Left-right policy position
* p_eudif					= Pro-anti European integration position
* year						= Election year
* country					= Country of origin of party
* europarty					= Europarty
* party						= Party



* =================================
* Table 1: Descriptive statistics
* =================================

sum dist_rile dist_rile_eu lagseats_rel dist_voter_rile dist_voter_rile_eu logmemduration salience govern lagdist_rile lagdist_rile_eu
tab govern



* ==========================
* Table 2: Main analysis
* ==========================

* RILE 
regress dist_rile lagseats_rel dist_voter_rile logmemduration salience govern lagdist_rile, vce(cluster party_year)

* Two dimensions 
regress dist_rile_eu lagseats_rel dist_voter_rile_eu logmemduration salience govern lagdist_rile_eu, vce(cluster party_year)




* =============================================
* Table 3: Alternative model specifications
* =============================================


* Controling for party families
* =============================

* RILE
regress dist_rile lagseats_rel dist_voter_rile logmemduration salience govern lagdist_rile i.pfamily, vce(cluster party_year)

* Two dimensions
regress dist_rile_eu lagseats_rel dist_voter_rile_eu logmemduration salience govern lagdist_rile_eu i.pfamily, vce(cluster party_year)



* National position from last election
* ====================================

* RILE
regress dist_rile_lagged lagseats_rel dist_voter_rile_lagged logmemduration salience govern lagdist_rile_lagged, vce(cluster party_year)

* Two dimensions
regress dist_rile_eu_lagged lagseats_rel dist_voter_rile_eu_lagged logmemduration salience govern lagdist_rile_eu_lagged, vce(cluster party_year)



* Controling for population size
* ==============================

* RILE 
regress dist_rile lagseats_rel pophdth dist_voter_rile logmemduration salience govern lagdist_rile, vce(cluster party_year)

* Two dimensions 
regress dist_rile_eu lagseats_rel pophdth dist_voter_rile_eu logmemduration salience govern lagdist_rile_eu, vce(cluster party_year)


log close


