# =======================================================================
# Kluever/Rodon BJPS: Explaining policy position choice of Europarties
# =======================================================================


# Loading Packages
library(foreign)
library(nlme)
library(lattice)
library(Matrix)
library(lme4)
library(car)
library(arm)
library(memisc)
library(mice)
library(Zelig)
library(plotrix)  
library(sandwich)    
options(scipen=3)      
library(Ecdat)

 

# Loading data
rm(list=ls(all=TRUE))
setwd("C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive")
rawdat <- read.dta("KlueverRodonBJPS.dta")
attach(rawdat)
ctry <- as.numeric(country)
dat <- data.frame(europarty, ctry, country, rile, year, dist_rile)
detach(rawdat)
attach(dat)



# ==================
# I: DENSITY GRAPH
# ==================


# Getting the density data for each EU party
con_data <- subset(dat, europarty==1 & ctry > 1 & year == 2004)
str(con_data$rile)
summary(con_data$rile)
con <- density(con_data$rile)               

soc_data <- subset(dat,europarty==2 & ctry > 1 & year == 2004)
str(soc_data$rile)
summary(soc_data$rile)
soc <- density(soc_data$rile)  

lib_data <- subset(dat,europarty==4 & ctry > 1  & year == 2004)
str(lib_data$rile)
summary(lib_data$rile)
lib <- density(lib_data$rile)  

green_data <- subset(dat,europarty==3  & ctry > 1 & year == 2004)
str(green_data$rile)
summary(green_data$rile)
green <- density(green_data$rile)  


# Computing the graph with median
pdf(file="C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive/density_parties2004_median.pdf", height=8, width=10)  
par(mfrow=c(2,2), mar=c(5,5,2,3))

plot(green, main="EGP (14 parties)", xlim=c(-60,40), xlab="Left-Right Score", ylab="Density", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      abline(v=-38.8535, lty=5)    
      abline(v=-27.69, lty=3)    
      legend(10, 0.037, bty = "n", c("Europarty"), lty=5)
      legend(10, 0.0345, bty = "n", c("Median"), lty=3)
plot(soc, main="PES (27 parties)", xlim=c(-60,40), xlab="Left-Right Score", ylab="Density", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      abline(v=-12.98701, lty=5)  
      abline(v=-19.550, lty=3)         
      legend(10, 0.0515, bty = "n", c("Europarty"), lty=5)
      legend(10, 0.048, bty = "n", c("Median"), lty=3)
plot(lib, main="ELDR (27 parties)", xlim=c(-60,40), xlab="Left-Right Score", ylab="Density", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      abline(v=-10.81594, lty=5)
      abline(v=-10.820, lty=3) 
      legend(10, 0.041, bty = "n", c("Europarty"), lty=5)
      legend(10, 0.038, bty = "n", c("Median"), lty=3)
plot(con, main="EPP(35 parties)",xlim=c(-60,40),  xlab="Left-Right Score", ylab="Density", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      abline(v=5.813953, lty=5)
      abline(v=1.220, lty=3)   
      legend(10, 0.043, bty = "n", c("Europarty"), lty=5)
      legend(10, 0.040, bty = "n", c("Median"), lty=3)         
dev.off()





    
# =============================================
# Figure 2: Histogram of left-right distances
# =============================================


# Getting the data for each Europarty
con_data_hist <- subset(dat,europarty==1)              
soc_data_hist <- subset(dat,europarty==2)
lib_data_hist <- subset(dat,europarty==4)
green_data_hist <- subset(dat,europarty==3)




# Computing the plot
pdf(file="C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive/hist_dist.pdf", height=8, width=10)  
par(mfrow=c(2,2), mar=c(5,5,2,3))
hist(con_data_hist$dist_rile,  main="EPP", xlim=c(0,50), col="grey60", xlab="Left-Right Distance", ylab="Frequency", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      text(39, 21, "Mean=12.48", col="black", cex=1.0, adj = c(0,0))
      text(39, 19, "Stdev=9.67", col="black", cex=1.0, adj = c(0,0))
hist(soc_data_hist$dist_rile, main="PES",  xlim=c(0,50),col="grey60", xlab="Left-Right Distance", ylab="Frequency", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      text(39, 30, "Mean=9.86", col="black", cex=1.0, adj = c(0,0))
      text(39, 27, "Stdev=9.82", col="black", cex=1.0, adj = c(0,0))
hist(lib_data_hist$dist_rile, main="ELDR",  xlim=c(0,50), col="grey60", xlab="Left-Right Distance", ylab="Frequency", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      text(39, 21, "Mean=9.26", col="black", cex=1.0, adj = c(0,0))
      text(39, 19, "Stdev=7.39", col="black", cex=1.0, adj = c(0,0))
hist(green_data_hist$dist_rile, main="EGP", xlim=c(0,50), col="grey60", xlab="Left-Right Distance", ylab="Frequency", 
      cex=1.3, cex.axis=1.3, cex.lab=1.5, cex.main = 1.5)
      text(39, 11, "Mean=11.99", col="black", cex=1.0, adj = c(0,0))
      text(39, 10, "Stdev=10.83", col="black", cex=1.0, adj = c(0,0))
dev.off()






# =======================================================
# Figure 3a and 3b: The effect of legislative resources
# =======================================================

# ============================
# Figure 3a: Left-right space
# ============================

# Loading data
# =============

rm(list=ls(all=TRUE))
setwd("C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive")
dat <- read.dta("KlueverRodonBJPS.dta")
eu_party <- as.integer(dat$euparty)
daten <- na.omit(data.frame(dat$dist_rile, dat$dist_voter_rile, dat$lagseats_rel, dat$logmemduration, dat$salience, dat$govern, dat$lagdist_rile, dat$party_year))
str(daten)


# 1. Model
# ========

fit7 <- lm(dat.dist_rile ~ dat.lagseats_rel + dat.dist_voter_rile + dat.logmemduration + dat.salience + dat.govern + dat.lagdist_rile,  data=daten)
summary(fit7)

source("clx_mclx.R")
(clfit7 <- clx(fit7, 1, daten$dat.party_year))


# 2. Computing variance covariance matrix
# =======================================
M <- length(unique(daten$dat.party_year))
N <- length(daten$dat.party_year)
K <- fit7$rank
dfc <- (M/(M-1))*((N-1)/(N-K))
uj  <- apply(estfun(fit7),2, function(x) tapply(x, daten$dat.party_year, sum))
vcovCL <- dfc*sandwich(fit7, meat=crossprod(uj)/N)

(V <- as.matrix(vcovCL))		   # Variance-covariance matrix
(sqrt(diag(V)))                # Clustered standard errors


# 3. Getting coefficients
# =======================
str(fit7)
b <- fit7$coefficients



# 4. Set up MVN distribution
# ===============================
nsim <- 1000
mvn <- mvrnorm(nsim, mu=b, Sigma=V)


# 5. Computing predicted values
# ==================================

yhat <- list(rep(NA,40))
for (i in 1:40){                                               
yhat[[i]] = (
              mvn[,2] * i
            + mvn[,3] * (mean(daten$dat.dist_voter_rile))
            + mvn[,4] * (mean(daten$dat.logmemduration))
            + mvn[,5] * (mean(daten$dat.salience))
            + mvn[,6] * (mean(daten$dat.govern))
            + mvn[,7] * (mean(daten$dat.lagdist_rile))
            + mvn[,1] * 1
            )
}


# 6. Transform list into matrix
# =============================

yhat_matrix <- do.call(cbind, yhat)


# 7. Taking the means and quantiles of simulated values
# =====================================================

yhat_mean <- list(rep(NA,40))
yhat_lb <- list(rep(NA,40))
yhat_ub <- list(rep(NA,40))

for (i in 1:40){
 yhat_mean[[i]] <- mean(yhat_matrix[,i])
 yhat_lb[[i]] <- quantile(yhat_matrix[,i], c(.025))
 yhat_ub[[i]] <- quantile(yhat_matrix[,i], c(.975))
}


mean <- unlist(yhat_mean)
lb <- unlist(yhat_lb)
ub <- unlist(yhat_ub)
xval <- 1:40

results <- data.frame(xval,mean, lb, ub)


# 8. Plotting predicted probabilites
# ===================================

pdf(file="C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive/predicted_rile_new.pdf", height=8, width=11)
par(mfrow=c(1,1),mar=c(5,5,1.5,3))
plot(xval, mean, type="l", col="black", lwd=2, xlim=c(0,40), ylim=c(0,20), xlab="Legislative resources",
      ylab="Predicted distance", cex=1.5, cex.axis=2.0, cex.lab=2.5)
      lines(xval, ub, col="black", lty=2, lwd=2)
      lines(xval, lb, col="black", lty=2, lwd=2)
      legend(0, 2, bty = "n", "Point estimate", lwd=2, col="black", cex=1.5)
      legend(0, 1, bty = "n", "95% Confidence interval", lwd=2, lty=2, col="black", cex=1.5)
dev.off()




# =================================
# Figure 3b: Two-dimensional space
# =================================


# Loading data
# =============

rm(list=ls(all=TRUE))
setwd("C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive")
dat <- read.dta("KlueverRodonBJPS.dta")
eu_party <- as.integer(dat$euparty)
daten <- na.omit(data.frame(dat$dist_rile_eu, dat$dist_voter_rile_eu, dat$lagseats_rel, dat$logmemduration, dat$salience, dat$govern, dat$lagdist_rile_eu, dat$party_year))
str(daten)


# 1. Model
# ========

fit7 <- lm(dat.dist_rile_eu ~ dat.lagseats_rel + dat.dist_voter_rile_eu + dat.logmemduration + dat.salience + dat.govern + dat.lagdist_rile_eu,  data=daten)
summary(fit7)

source("clx_mclx.R")
(clfit7 <- clx(fit7, 1, daten$dat.party_year))


# 2. Computing variance covariance matrix
# =======================================
M <- length(unique(daten$dat.party_year))
N <- length(daten$dat.party_year)
K <- fit7$rank
dfc <- (M/(M-1))*((N-1)/(N-K))
uj  <- apply(estfun(fit7),2, function(x) tapply(x, daten$dat.party_year, sum))
vcovCL <- dfc*sandwich(fit7, meat=crossprod(uj)/N)

(V <- as.matrix(vcovCL))		   # Variance-covariance matrix
(sqrt(diag(V)))                # Clustered standard errors


# 3. Getting coefficients
# =======================
str(fit7)
b <- fit7$coefficients



# 4. Set up MVN distribution
# ===============================
nsim <- 1000
mvn <- mvrnorm(nsim, mu=b, Sigma=V)


# 5. Computing predicted values
# ==================================

yhat <- list(rep(NA,40))
for (i in 1:40){                                               
yhat[[i]] = (
              mvn[,2] * i
            + mvn[,3] * (mean(daten$dat.dist_voter_rile_eu))
            + mvn[,4] * (mean(daten$dat.logmemduration))
            + mvn[,5] * (mean(daten$dat.salience))
            + mvn[,6] * (mean(daten$dat.govern))
            + mvn[,7] * (mean(daten$dat.lagdist_rile_eu))
            + mvn[,1] * 1
            )
}


# 6. Transform list into matrix
# =============================

yhat_matrix <- do.call(cbind, yhat)


# 7. Taking the means and quantiles of simulated values
# =====================================================

yhat_mean <- list(rep(NA,40))
yhat_lb <- list(rep(NA,40))
yhat_ub <- list(rep(NA,40))

for (i in 1:40){
 yhat_mean[[i]] <- mean(yhat_matrix[,i])
 yhat_lb[[i]] <- quantile(yhat_matrix[,i], c(.025))
 yhat_ub[[i]] <- quantile(yhat_matrix[,i], c(.975))
}


mean <- unlist(yhat_mean)
lb <- unlist(yhat_lb)
ub <- unlist(yhat_ub)
xval <- 1:40

results <- data.frame(xval,mean, lb, ub)


# 8. Plotting predicted probabilites
# ===================================

pdf(file="C:/Users/Heike/Dropbox/Party Paper/BJPS Replication Archive/predicted_rile_eu_new.pdf", height=8, width=11)
par(mfrow=c(1,1),mar=c(5,5,1.5,3))
plot(xval, mean, type="l", col="black", lwd=2, xlim=c(0,40), ylim=c(0,20), xlab="Legislative resources",
      ylab="Predicted distance", cex=1.5, cex.axis=2.0, cex.lab=2.5)
      lines(xval, ub, col="black", lty=2, lwd=2)
      lines(xval, lb, col="black", lty=2, lwd=2)
      legend(0, 2, bty = "n", "Point estimate", lwd=2, col="black", cex=1.5)
      legend(0, 1, bty = "n", "95% Confidence interval", lwd=2, lty=2, col="black", cex=1.5)
dev.off()
